---
title: <span class="badge object-type-scalar"></span> ClockSeconds
---
# <span class="badge object-type-scalar"></span> ClockSeconds

Time: clock (s)

## Definition

```python
# Time: clock (s)
ClockSeconds: typing.Literal["clocks"] = "clocks"
```
